%global momorel 2
%global docver 0.3.2

Summary: A photographic lens database and a library for accessing it
Name: lensfun
Version: 0.3.2
Release: %{momorel}m%{?dist}
License: LGPLv3
Group: System Environment/Libraries
URL: http://lensfun.sourceforge.net/
Source0: http://dl.sourceforge.net/project/%{name}/%{version}/%{name}-%{version}.tar.gz
NoSource: 0

## upstream patches
Patch1: 0001-Only-require-glib-2.40-when-tests-are-build-without-.patch
Patch38: 0038-Only-use-proper-C-new-and-delete-syntax-for-object-c.patch
Patch58: 0058-Use-database-in-source-directory-while-running-tests.patch
Patch59: 0059-Patch-47-respect-DESTDIR-when-installing-python-stuf.patch
Patch60: 0060-Various-CMake-patches-from-the-mailing-list.patch
Patch113: 0113-Added-std-namespace-to-isnan.patch

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires: cmake
BuildRequires: doxygen
BuildRequires: glib2-devel
BuildRequires: libpng-devel
BuildRequires: python
BuildRequires: python3-devel
BuildRequires: zlib-devel

%description
The goal of the lensfun library is to provide a open source database
of photographic lenses and their characteristics. In the past there
was a effort in this direction (see http://www.epaperpress.com/ptlens/),
but then author decided to take the commercial route and the database
froze at the last public stage. This database was used as the basement
on which lensfun database grew, thanks to PTLens author which gave his
permission for this, while the code was totally rewritten from scratch
(and the database was converted to a totally new, XML-based format).

The lensfun library not only provides a way to read the database and
search for specific things in it, but also provides a set of algorithms
for correcting images based on detailed knowledge of lens properties
and calibration data. Right now lensfun is designed to correct distortion,
transversal (also known as lateral) chromatic aberrations, vignetting
and colour contribution index of the lens.

%package devel
Summary: lensfun development files for %{name}
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}
Requires: pkgconfig

%description devel
Header and library definition files for developing applications
that use the lensfun library/database.

%package -n python3-%{name}
Summary:  Python3 lensfun bindings
Requires: %{name} = %{version}-%{release}

%description -n python3-%{name}
%{summary}.

%prep
%setup -q

# upstream patches
%patch1 -p1 -b .0001
%patch38 -p1 -b .0038
%patch58 -p1 -b .0058
%patch59 -p1 -b .0059
%patch60 -p1 -b .0060
%patch113 -p1 -b .0113

%build
mkdir -p %{_target_platform}
pushd %{_target_platform}
%{cmake} \
  -DBUILD_DOC:BOOL=ON \
  -DBUILD_TESTS:BOOL=OFF \
  ..
popd

make %{?_smp_mflags} -C %{_target_platform} VERBOSE=1
make doc -C %{_target_platform}

%install
[ "%{buildroot}" != "/" ] && rm -rf %{buildroot}
make install DESTDIR=%{buildroot} -C %{_target_platform}

%clean
[ "%{buildroot}" != "/" ] && rm -rf %{buildroot}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc README.md
%doc docs/cc-by-sa-3.0.txt
%doc docs/gpl-3.0.txt
%doc docs/lgpl-3.0.txt
%doc docs/manual-main.txt
%doc docs/mounts.txt
%{_bindir}/g-lensfun-update-data
%{_bindir}/lensfun-add-adapter
%{_bindir}/lensfun-update-data
%{_libdir}/lib%{name}.so.*
%{_datadir}/%{name}
%{_datadir}/doc/%{name}
%{_mandir}/man1/*

%files devel
%defattr(-,root,root,-)
%doc %{_target_platform}/doc_doxygen/*.css
%doc %{_target_platform}/doc_doxygen/*.html
%doc %{_target_platform}/doc_doxygen/*.png
%{_includedir}/%{name}
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/lib%{name}.so

%files -n python3-%{name}
%defattr(-,root,root,-)
%{python3_sitelib}/lensfun
%{python3_sitelib}/lensfun*.egg-info

%changelog
* Thu May 18 2017 Ichiro Nakai <ichiro@n.email.ne.jp>
- (0.3.2-2m)
- apply upstream patches
- add a package python3-lensfun

* Thu Jan 05 2017 Yohsuke Ooi <meke@momonga-linux.org>
- (0.3.2-1m)
- version 0.3.2

* Fri May 16 2014 Ichiro Nakai <ichiro@n.email.ne.jp>
- (0.2.8-1m)
- version 0.2.8

* Thu Jun 28 2012 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (0.2.5-7m)
- rebuild for glib 2.33.2

* Mon Apr 11 2011 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (0.2.5-6m)
- rebuild for new GCC 4.6

* Tue Mar  8 2011 Ichiro Nakai <ichiro@n.email.ne.jp>
- (0.2.5-5m)
- import cpuid.patch from Fedora to avoid crashing of ufraw-0.17 or higher
- https://bugzilla.redhat.com/show_bug.cgi?id=631674

* Sun Nov 28 2010 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (0.2.5-4m)
- rebuild for new GCC 4.5

* Tue Aug 31 2010 Yohsuke Ooi <meke@momonga-linux.org>
- (0.2.5-3m)
- full rebuild for mo7 release

* Sun Jul  4 2010 Ichiro Nakai <ichiro@n.email.ne.jp>
- (0.2.5-2m)
- touch up spec file

* Fri Apr  2 2010 Ichiro Nakai <ichiro@n.email.ne.jp>
- (0.2.5-1m)
- version 0.2.5
- clean up spec file

* Sun Nov 22 2009 Ichiro Nakai <ichiro@n.email.ne.jp>
- (0.2.4-1m)
- [CRASH FIX] version 0.2.4, ufraw is working fully on trunk now
- remove merged trunk_db.patch

* Sat Nov 14 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (0.2.3-4m)
- rebuild against gcc-4.4 and glibc-2.11

* Wed Jan 21 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (0.2.3-3m)
- rebuild against rpm-4.6

* Wed Dec 31 2008 Shigeyuki Yamashita <shige@momonga-linux.org>
- (0.2.3-2m)
- append "NoSource: 0"

* Tue Dec 30 2008 Shigeyuki Yamashita <shige@momonga-linux.org>
- (0.2.3-1m)
- Initial specfile for Momonga.
